Learn R Programming

redlistr (version 2.1.0)

jplot: Make elbow plot to check jitter iterations

Description

jplot creates an elbow plot of the min AOO against the number of grid replicates run. Jplots that fall to the minimum value well before the highest n are robust.

Usage

jplot(x)

Value

NULL; plots min AOO against number of reps

Arguments

x

an AOOgrid object

Author

Aniko B. Toth anikobtoth@gmail.com

See Also

Other AOO functions: createGrid(), getAOO(), makeAOOGrid(), top_pct()