createGrid produces empty grid which can be used as the basis to help
compute AOO.
Value
A regular grid raster with extent input_data expanded by two
cells in each direction and grid size cell_size. Each grid square has a
unique raster value that serves as its identification number.
References
Bland, L.M., Keith, D.A., Miller, R.M., Murray, N.J. and Rodriguez, J.P. (eds.) 2016. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 1.0. Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
See also
Other AOO functions:
getAOO(),
jplot(),
makeAOOGrid(),
top_pct()
Author
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com, Aniko B. Toth anikobtoth@gmail.com