getAOO determines the number of area of occupancy (AOO) grid cells
occupied by a species or ecosystem. It includes capability for specifying
whether at least one percent of the grid cell needs to be occupied before it
is counted in the AOO. This functionality is important for assessing the IUCN
Red List of Ecosystems Criteria B.
getAOO(
input_data,
cell_size = 10000,
names_from = NA,
bottom_1pct_rule = TRUE,
percent = 1,
jitter = 150,
n_jitter = 35
)an object of class AOOgrid or a list of AOOgrid objects. Ecosystems that received an AOO of 60 cells or fewer on a first pass are run with a jittered grid with n specified by n_jitter
Spatial object (sf or SpatRaster) of an ecosystem or species distribution. Please use a CRS with units measured in metres.
A number specifying the width of the desired grid square (in same units as your coordinate reference system)
the name of the column containing ecosystem labels
Logical. If TRUE, grid cells containing the least
ecosystem area are dropped up to 1% of the total distribution.
Numeric. The minimum percent to be applied as a threshold for
the bottom_1pct_rule
Integer. 0 = do not jitter, 1 = force jitter, another number indicates conditional jitter, the number of AOO cells under which to jitter, and over which not to jitter the grid.
the number of grids to test for ecosystems near the AOO thresholds. Ignored if jitter = FALSE.
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com, Aniko B. Toth anikobtoth@gmail.com
Bland, L.M., Keith, D.A., Miller, R.M., Murray, N.J. and Rodriguez, J.P. (eds.) 2016. Guidelines for the application of IUCN Red List of Ecosystems Categories and Criteria, Version 1.0. Gland, Switzerland: IUCN. ix + 94pp. Available at the following web site: https://iucnrle.org/
Other AOO functions:
createGrid(),
jplot(),
makeAOOGrid(),
top_pct()