getAreaTrend is used to calculate changes in area over time. Output
is a list can be used to easily visualise trends for one ecosystem at a time.
See also
Other Change functions:
getArea(),
getAreaChange(),
getDeclineStats()
Author
Aniko B. Toth anikobtoth@gmail.com