Learn R Programming

redlistr (version 2.1.0)

getAreaTrend: Calculate area trends of ecosystems

Description

getAreaTrend is used to calculate changes in area over time. Output is a list can be used to easily visualise trends for one ecosystem at a time.

Usage

getAreaTrend(x, names_from = NA)

Value

returns a list

Arguments

x

SpatRaster with multiple layers or data frame containing two numerical columns "area" and "time". The data.frame can contain an additional column containing a key, whose name should be placed in names_from.

names_from

name of column containing ecosystem labels. Ignored if x is a raster.

Author

Aniko B. Toth anikobtoth@gmail.com

See Also

Other Change functions: declineForecast(), getArea(), getAreaChange(), getDeclineStats()