getAreaTrend is used to calculate changes in area over time. Output
is a list can be used to easily visualise trends for one ecosystem at a time.
getAreaTrend(x, names_from = NA)returns a list
SpatRaster with multiple layers or data frame containing two numerical columns "area" and "time". The data.frame can contain an additional column containing a key, whose name should be placed in names_from.
name of column containing ecosystem labels. Ignored if x is a raster.
Aniko B. Toth anikobtoth@gmail.com
Other Change functions:
declineForecast(),
getArea(),
getAreaChange(),
getDeclineStats()