Calculates area of the created EOO polygon and returns a summary object with useful info.
Source:R/EOO_functions.R
getEOO.RdgetEOO calculates the area of the EOO polygon generated from
makeEOO the provided data and returns an EOO class object or a list of these with
defined summary and plot functions available.
Value
An object of type EOO or a list of EOO objects that store the EOO polygon, its area, and its input.data
See also
Other EOO functions:
getAreaEOO(),
makeEOO()
Author
Nicholas Murray murr.nick@gmail.com, Calvin Lee calvinkflee@gmail.com