powered by
jplot creates an elbow plot of the min AOO against the number of grid replicates run. Jplots that fall to the minimum value well before the highest n are robust.
jplot
jplot(x)
NULL; plots min AOO against number of reps
an AOOgrid object
Aniko B. Toth anikobtoth@gmail.com
Other AOO functions: createGrid(), getAOO(), makeAOOGrid(), top_pct()
createGrid()
getAOO()
makeAOOGrid()
top_pct()