A class to represent change in area over time for an ecosystem.
Slots
inputbinary raster or list of sf POLYGON objects representing the input ecosystem extent
areasthe area of the ecosystem in each layer or list element
modela fitted model object typically of the class lm containing the model used to calculate the trend
netdiffdifference between the area in the first layer or list element and the last.
diffraster stack showing change over layers or list elements of the ecosystem extent.